#!/usr/bin/env python
# -*- coding: utf-8 -*-

# geoarray, A fast Python interface for image geodata - either on disk or in memory.
#
# Copyright (C) 2019  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
#
# This software was developed within the context of the GeoMultiSens project funded
# by the German Federal Ministry of Education and Research
# (project grant code: 01 IS 14 010 A-C).
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
test_masks
----------

Tests for the geoarray.masks module.
"""

from unittest import TestCase
import numpy as np

from geoarray import NoDataMask, BadDataMask


class Test_NoDataMask(TestCase):
    def test_init_from_bool(self):
        NoDataMask(np.array([[True, False], [False, False]]))

    def test_init_from_int(self):
        NoDataMask(np.array([[1, 0], [0, 0]]))

    def test_init_out_of_range(self):
        with self.assertRaises(AssertionError):
            NoDataMask(np.array([[2, 0], [5, 0]]))

        with self.assertRaises(AssertionError):
            NoDataMask(np.array([[5, 2], [2, 5]]))


class Test_BadDataMask(TestCase):
    def test_init_from_bool(self):
        BadDataMask(np.array([[True, False], [False, False]]))

    def test_init_from_int(self):
        BadDataMask(np.array([[1, 0], [0, 0]]))

    def test_init_out_of_range(self):
        with self.assertRaises(AssertionError):
            BadDataMask(np.array([[2, 0], [5, 0]]))

        with self.assertRaises(AssertionError):
            BadDataMask(np.array([[5, 2], [2, 5]]))
